@@ -2,10 +2,13 @@ from typing import Any, Optional
 import requests
 
 from .auth import Authenticator
+from .v3.aws_integration import AwsIntegration
 from .v3.devices import Devices
+from .v3.dialects import Dialects
 from .v3.domains import Domains
 from .v3.data_model import DataModel
 from .v3.device_monitoring import DeviceMonitoring
+from .v3.lifecycle_management import LifecycleManagement
 from .v3.sessions import Sessions
 from .v3.setting_values import SettingValues
 from .v3.task_templates import TaskTemplates
@@ -37,10 +40,13 @@ class Coiote:
         self.authenticator = Authenticator(
             self.url, self.session, auth=auth)
 
+        self.aws_integration: AwsIntegration = self._make_module(AwsIntegration)
         self.data_model: DataModel = self._make_module(DataModel)
         self.device_monitoring: DeviceMonitoring = self._make_module(DeviceMonitoring)
         self.devices: Devices = self._make_module(Devices)
+        self.dialects: Dialects = self._make_module(Dialects)
         self.domains: Domains = self._make_module(Domains)
+        self.lifecycle_management: LifecycleManagement = self._make_module(LifecycleManagement)
         self.sessions: Sessions = self._make_module(Sessions)
         self.setting_values: SettingValues = self._make_module(SettingValues)
         self.task_reports: TaskReports = self._make_module(TaskReports)
