@@ -64,12 +64,16 @@ def _safe_get_json(response: Optional[Response]):
 
 def _make_error(msg: str, response: Optional[Response]):
     json = _safe_get_json(response)
-    return ValueError(f"{msg}\nHeaders:{response.headers}\nBody: {json}")
+    headers = response.headers if response else None
+    return ValueError(f"{msg}\nHeaders:{headers}\nBody: {json}")
 
 
 def handle_response(response: Response, dataclass: Optional[Any]):
     try:
-        return deserialize(json=response.json(), dataclass=dataclass)
+        if response.status_code != 204:
+            return deserialize(json=response.json(), dataclass=dataclass)
+        else:
+            return None
     except:
         if response.status_code == 404:
             return None
