@@ -13,23 +13,23 @@ class Domains(ApiEndpoint):
 
     @api_call()
     def get_all(self, search_criteria: Optional[str] = None) -> List[str]:
-        return self.session.get(super()._make_url(), params={"searchCriteria": search_criteria})
+        return self.session.get(self.get_url(), params={"searchCriteria": search_criteria})
 
     @api_call(StringResult)
     def add_domain(self, domain: Domain) -> StringResult:
-        return self.session.post(super()._make_url(), json=asdict(domain))
+        return self.session.post(self.get_url(), json=asdict(domain))
 
     @api_call(Domain)
     def get_one(self, domain_id: str) -> Domain:
         safe_domain = sanitize_request_param(domain_id)
-        return self.session.get(super()._make_url(f"/{safe_domain}"))
+        return self.session.get(self.get_url(f"/{safe_domain}"))
 
     @api_call()
     def update_one(self, domain_id: str, update: DomainUpdateRequest) -> None:
         safe_domain = sanitize_request_param(domain_id)
-        return self.session.put(super()._make_url(f"/{safe_domain}"), json=asdict(update))
+        return self.session.put(self.get_url(f"/{safe_domain}"), json=asdict(update))
 
     @api_call()
     def delete_one(self, domain_id: str) -> None:
         safe_domain = sanitize_request_param(domain_id)
-        return self.session.delete(super()._make_url(f"/{safe_domain}"))
+        return self.session.delete(self.get_url(f"/{safe_domain}"))
